@@ -1,5 +1,13 @@
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #include "uulib/clear.h"
 
+#ifdef __cplusplus
+}
+#endif
+
 void uu_clear(struct uu *io) {
   io->time_low              = 0;
   io->time_mid              = 0;
