@@ -1,7 +1,7 @@
 #ifndef UU_CLEAR_H
 #define UU_CLEAR_H
 
-#include "uulib/CONF.h"
+#include "uulib/UUID.h"
 
 void uu_clear(struct uu *io);
 
