@@ -1,7 +1,7 @@
 #ifndef UU_CLOCK_H
 #define UU_CLOCK_H
 
-#include "uulib/CONF.h"
+#include "uulib/UUID.h"
 
 /* Assume that the gettimeofday() has microsecond granularity */
 #define MAX_ADJUSTMENT 10
