@@ -1,7 +1,7 @@
 #ifndef UU_COMPARE_H
 #define UU_COMPARE_H
 
-#include "uulib/CONF.h"
+#include "uulib/UUID.h"
 
 IV uu_cmp_binary(const uu_t uu1, const uu_t uu2);
 IV uu_cmp_struct1(const struct uu *us1, const struct uu *us2);
