@@ -1,5 +1,13 @@
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #include "uulib/copy.h"
 
+#ifdef __cplusplus
+}
+#endif
+
 void uu_copy_binary(const uu_t in, uu_t out) {
   U8  *cp1 = (U8*)&in;
   U8  *cp2 = out;
