@@ -1,7 +1,7 @@
 #ifndef UU_COPY_H
 #define UU_COPY_H
 
-#include "uulib/CONF.h"
+#include "uulib/UUID.h"
 
 void uu_copy_binary(const uu_t in, uu_t out);
 void uu_copy_struct(const struct uu *in, struct uu *out);
