@@ -1,9 +1,9 @@
 #ifndef UU_NODE_H
 #define UU_NODE_H
 
-#include "uulib/CONF.h"
+#include "uulib/UUID.h"
 
-IV uu_get_node_id(U8 *node_id);
+int uu_get_node_id(U8 *node_id);
 
 #endif
 /* ex:set ts=2 sw=2 itab=spaces: */
