@@ -1,6 +1,14 @@
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #include "uulib/splitmix.h"
 #include "uulib/gettime.h"
 
+#ifdef __cplusplus
+}
+#endif
+
 /* based on splitmix64
  * https://xorshift.di.unimi.it/splitmix64.c
 */
