@@ -1,5 +1,13 @@
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #include "uulib/unpack.h"
 
+#ifdef __cplusplus
+}
+#endif
+
 void uu_unpack(const uu_t in, struct uu *out) {
   const U8  *ptr = in;
   U32       tmp;
