@@ -1,9 +1,9 @@
 #ifndef UU_UTIL_H
 #define UU_UTIL_H
 
-#include "uulib/CONF.h"
+#include "uulib/UUID.h"
 
-IV uu_time(const struct uu *in, struct timeval *out);
+NV uu_time(const struct uu *in);
 UV uu_type(const struct uu *in);
 UV uu_variant(const struct uu *in);
 
