@@ -1,6 +1,14 @@
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #include "uulib/xoshiro.h"
 #include "uulib/splitmix.h"
 
+#ifdef __cplusplus
+}
+#endif
+
 /* based on xoshiro256++
  * https://prng.di.unimi.it/xoshiro256plusplus.c
 */
