@@ -1,7 +1,7 @@
 #ifndef UU_XOSHIRO_H
 #define UU_XOSHIRO_H
 
-#include "uulib/CONF.h"
+#include "uulib/UUID.h"
 
 void xo_srand(void);
 U64  xo_rand(void);
